@@ -265,8 +265,10 @@ proc query_from_selection {} {
         set Query(query_pr_opts) "$prid_list"
     } {
         set Query(query_pr_opts) ""
+	set sep ""
 	foreach prid $prid_list {
-	    append Query(query_pr_opts) "Number==$prid_list|"
+	    append Query(query_pr_opts) [concat $sep "Number==$prid_list"]
+	    set sep "|"
 	}
 	append Query(query_pr_opts) " "
     }
@@ -1132,8 +1134,10 @@ proc save_query_cmd {mode} {
         if {$mode != "save"} {
             set Query(default__query) [list proc default__query {flds} {return 1}]
 	    set Query(query_pr_opts) ""
+	    set sep ""
 	    foreach prid $prid_list {
-		append Query(query_pr_opts) "Number==$prid_list|"
+		append Query(query_pr_opts) [concat $sep "Number==$prid_list"]
+		set sep "|"
 	    }
 	    append Query(query_pr_opts) " "
             set Query(by_id_only) 1
@@ -1581,7 +1585,7 @@ proc query_cmd_socket {} {
 
     foreach cmd $clist {
 	dputs "query sending $cmd"
-        puts $s $cmd
+        gnatsd_send $s $cmd
         set rep [get_socket_reply $s]
         if {![string match 210* [lindex $rep 0]]} {
             Msg "GNATSD error on cmd: $cmd\n" "[join $rep \n]"
@@ -1592,7 +1596,7 @@ proc query_cmd_socket {} {
 
     set prdata ""
 
-        puts $s "QUER"
+       gnatsd_send $s "QUER"
         
         set rep [get_socket_reply $s]
         if {[string match 440* [lindex $rep 0]]} {
@@ -1863,14 +1867,20 @@ menu       .mframe.help.m
 pack .mframe.help -side right
 
 frame .eflds
+set panelnum 0
 radiobar_frame .eflds .eflds.lb
 foreach {efield elist} [list Class $TkGnats(ClassesList) State $TkGnats(StatesList) Priority {low medium high} Severity {non-critical serious critical} Confidential {no yes}] {
     if {![check_suppressed_field $efield]} {
-        checkbar .eflds.lb [string tolower $efield] $efield $elist All
+        checkbar .eflds.lb [string tolower $efield] $efield $elist All $panelnum
+	incr panelnum
     }
 }
+pack .eflds.lb -side left -pady 0
 pack .eflds -side top  -padx  0 -fill x -anchor w
 
+#puts stderr [concat "query boxes: " [grid slaves .eflds.lb]]
+
+
 frame .eboxs    
 set   nboxes 1
 array set xpad {1 0 2 20 3 0}
