@@ -1,6 +1,5 @@
 /* Commands for the GNATS server.
-   Copyright (C) 2001 Milan Zamazal
-   Copyright (C) 1994, 95, 95, 1997 Free Software Foundation, Inc.
+   Copyright (C) 1994, 95, 95, 1997, 2001, 2002 Free Software Foundation, Inc.
    Contributed by Brendan Kehoe (brendan@cygnus.com).
    Further hacked by Milan Zamazal (pdm@zamazal.org) and other contributors.
 
@@ -319,11 +318,11 @@ GNATS_user (int ac, char **av)
       printf ("%d %s\r\n", CODE_INFORMATION,
 	      access_level_str (user_access));
     }
-  else if (ac == 2)
+  else if ((ac == 1) || (ac == 2))
     {
       if (databaseValid (currentDatabase))
 	{
-	  if (gnatsdChdb (databaseName (currentDatabase), av[0], av[1], 0,
+	  if (gnatsdChdb (databaseName (currentDatabase), av[0], ac == 2 ? av[1] : "", 0,
 			  &err) != 0)
 	    {
 	      print_server_errors (err);
@@ -340,14 +339,21 @@ GNATS_user (int ac, char **av)
 	      free (currentPassword);
 	    }
 	  currentUsername = xstrdup (av[0]);
-	  currentPassword = xstrdup (av[1]);
+	  if (ac == 2)
+	    {
+	      currentPassword = xstrdup (av[1]);
+	    }
+	  else
+	    {
+	      currentPassword = (char *)"";
+	    }
 	  printf ("%d Current database is not valid; use CHDB to set the database\r\n",
 		  CODE_OK);
 	}
     }
   else
     {
-      printf ("%d Need two arguments, username and password\r\n", 
+      printf ("%d Need one or two arguments, username and optionally a password\r\n", 
 	      CODE_CMD_ERROR);
     }
 }
@@ -404,7 +410,7 @@ GNATS_lock (int ac, char **av)
 
   if (ac < 2)
     {
-      printf ("%d Must lock with username, PR number, and process locking it.\r\n",
+      printf ("%d Must lock with PR number, username, and process locking it.\r\n",
 	      CODE_CMD_ERROR);
       return;
     }
@@ -592,15 +598,19 @@ gnatsdChdb (const char *nameOfDb, const char *username, const char *passwd,
 	  free (currentUsername);
 	}
       currentUsername = xstrdup (username);
-    }
-
-  if (passwd != NULL)
-    {
+      
       if (currentPassword != NULL)
 	{
 	  free (currentPassword);
 	}
-      currentPassword = xstrdup (passwd);
+      if (passwd != NULL)
+	{
+	  currentPassword = xstrdup (passwd);
+	}
+      else
+	{
+	  currentPassword = NULL;
+	}
     }
 
   if (currentUsername == NULL)
@@ -622,12 +632,13 @@ gnatsdChdb (const char *nameOfDb, const char *username, const char *passwd,
       if (! verifyHostAndUser (new_db, current_host, current_addr, 
 			       currentUsername, currentPassword, &access))
 	{
+	  const char *database_name = databaseName(new_db);
 	  /* Hmmm.  Should we still do this here? ??? XXX !!! */
 	  syslog (LOG_ERR, "host %s (%s) not allowed access for %s",
-		  current_host, current_addr, nameOfDb);
+		  current_host, current_addr, database_name);
 	  setError (err, CODE_NO_ACCESS, 
 		    "You are not permitted to access database %s.\r\n",
-		    nameOfDb);
+		    database_name);
 	  freeDatabaseInfo (new_db);
 	}
       else
@@ -670,9 +681,9 @@ GNATS_chdb (int ac, char **av)
   const char *user = NULL;
   const char *passwd = NULL;
 
-  if (ac != 1 && ac != 3)
+  if (ac != 1 && ac != 2 && ac != 3)
     {
-      printf ("%d One or three arguments required.\r\n", CODE_CMD_ERROR); 
+      printf ("%d One, two, or three arguments required.\r\n", CODE_CMD_ERROR); 
       return;
     }
 
@@ -681,6 +692,10 @@ GNATS_chdb (int ac, char **av)
       user = av[1];
       passwd = av[2];
     }
+  else if (ac == 2)
+    {
+      user = av[1];
+    }
 
   if (gnatsdChdb (av[0], user, passwd, 0, &err) != 0)
     {
@@ -1786,11 +1801,11 @@ GNATS_help (int ac ATTRIBUTE_UNUSED, char **av ATTRIBUTE_UNUSED)
  	  CODE_INFORMATION);
   printf ("%d-   SUBM                    submit a new PR\r\n",
 	  CODE_INFORMATION);
-  printf ("%d-   CHDB <database> [<user> <passwd>]\r\n",
+  printf ("%d-   CHDB <database> [<user> [<passwd>]]\r\n",
 	  CODE_INFORMATION);
   printf ("%d-                           change GNATS ROOT to <database>\r\n",
 	  CODE_INFORMATION);
-  printf ("%d-   USER <name> <passwd>    Sets the current user\r\n",
+  printf ("%d-   USER <name> [<passwd>]  Sets the current user\r\n",
 	  CODE_INFORMATION);
   printf ("%d-   USER                    Report current access level\r\n",
 	  CODE_INFORMATION);
