@@ -152,7 +152,7 @@ parseQueryFormat (const DatabaseInfo database, const char *expr,
   QueryFormat *res;
   FieldList currEnt = NULL;
 
-  while (expr[0] != '\0' && isspace ((int) expr[0]))
+  while (expr[0] != '\0' && isspace ((int)(unsigned char) expr[0]))
     {
       expr++;
     }
@@ -192,12 +192,12 @@ parseQueryFormat (const DatabaseInfo database, const char *expr,
       const char *nstart = expr;
       FieldList newEnt;
 
-      if (isspace ((int) expr[0]))
+      if (isspace ((int)(unsigned char) expr[0]))
 	{
 	  expr++;
 	  continue;
 	}
-      while ((! isspace ((int) expr[0])) && expr[0] != '\0')
+      while ((! isspace ((int)(unsigned char) expr[0])) && expr[0] != '\0')
 	{
 	  expr++;
 	}
@@ -324,7 +324,8 @@ static char case_fold[256];
 
 /* Return 0 if VALUE matched the regexp in PAT, 1 otherwise.  */
 int
-regcmp (const char *pat, const char *value, struct re_pattern_buffer *barg)
+gnats_regcmp (const char *pat, const char *value,
+	      struct re_pattern_buffer *barg)
 {
   struct re_pattern_buffer buf;
   struct re_pattern_buffer *bufPtr;
@@ -653,7 +654,8 @@ fieldCompare (PR *pr, PR *oldPR, QueryItem *fields,
       break;
 
     case RegCmp:
-      res = (regcmp (vals[1].value, vals[0].value, fields[1]->compRegexp) == 0);
+      res = (gnats_regcmp (vals[1].value, vals[0].value, fields[1]->compRegexp)
+	     == 0);
       break;
 
     case RegFind:
@@ -1406,8 +1408,8 @@ iterate_prs (const DatabaseInfo database, int ac, char **av, QueryExpr exp,
 
 	  while (pr != NULL)
 	    {
-	      if (regcmp (pat, field_value (pr, NUMBER (pr->database)), &buf) 
-		  == 0)
+	      if (gnats_regcmp (pat, field_value (pr, NUMBER (pr->database)),
+				&buf) == 0)
 		{
 		  if (pr_matches_expr (pr, NULL, exp, NULL))
 		    {
@@ -1613,11 +1615,11 @@ findMatchingQuote (const char *expr, const char *exprend)
 static void
 stripWhiteSpace (const char **expr, const char **expend)
 {
-  while (expr <= expend && isspace ((int) **expr))
+  while (expr <= expend && isspace ((int)(unsigned char) **expr))
     {
       (*expr)++;
     }
-  while (expr <= expend && isspace ((int) **expend))
+  while (expr <= expend && isspace ((int)(unsigned char) **expend))
     {
       (*expend)--;
     }
